@@ -37,8 +37,10 @@ UCB.
 from . import rule
 from .function import (
     AcquisitionFunction,
+    BatchAcquisitionFunction,
     AcquisitionFunctionBuilder,
     SingleModelAcquisitionBuilder,
+    BatchAcquisitionFunctionBuilder,
     ExpectedImprovement,
     expected_improvement,
     NegativeLowerConfidenceBound,
@@ -48,5 +50,7 @@ from .function import (
     probability_of_feasibility,
     ExpectedConstrainedImprovement,
     IndependentReparametrizationSampler,
+    MCIndAcquisitionFunctionBuilder,
+    SingleModelMCIndAcquisitionFunctionBuilder,
 )
 from .combination import Reducer, Product, Sum
